package sgc.portal.cw.cw1603.persistence;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw1603.model.CW16030001U;
import sgc.portal.cw.cw1603.dto.CW16030001USearch;

import java.util.List;

@Mapper
public interface CW16030001UMapper {
	
	
    List<EasyHashMap<String, Object>> getList(CW16030001USearch search);

    int insert(CW16030001U cW16030001U);

    int update(CW16030001U cW16030001U);

    int delete(CW16030001U cW16030001U);
    
    int updateStatus(CW16030001U cW16030001U);
    
    int saveSendCnt(CW16030001U cW16030001U);
    
    int deleteAtchfileId(CW16030001U cW16030001U);
    int selectAtchfileIdCount(CW16030001U cW16030001U);
	
	String selectRecvEmail(CW16030001U cW16030001U);
	
	String selectSenderEmail(CW16030001U cW16030001U);
	
	String selectRecvEmail2(CW16030001U cW16030001U);
	
	String selectWorkNm(CW16030001U cW16030001U);
}
